@@ -322,6 +322,13 @@ class SnowplowExtractedContextsPipeline(BaseExtractedContextsPipeline, ABC):
                 'se_category': ObjectivSupportedColumns.STACK_EVENT_TYPES.value,
             }
         )
+
+        # avoid having empty string in series that fill user_id series, otherwise
+        # there is a risk of raising an exception when trying to parse string values to UUID
+        uuid_series = ['network_userid', 'domain_sessionid']
+        for series in uuid_series:
+            df_cp.loc[df_cp[series] == '', series] = None
+
         # Anonymous users have no network_userid, but their domain_sessionid is useable as user_id as well
         df_cp[ObjectivSupportedColumns.USER_ID.value] = (
             df_cp['network_userid'].fillna(df_cp['domain_sessionid'])
